==> openai-assistantapi-1.0.2.tgz: package/README.md <==
# @brainstack/openai-assistantapi

The `@brainstack/openai-assistantapi` package simplifies interaction with OpenAI's Assistant API by providing an event-driven interface. It streamlines the process, allowing developers to focus on implementation rather than intricacies.

## Installation

Install the package via npm or yarn:

```bash
npm install @brainstack/openai-assistantapi
```

or

```bash
yarn add @brainstack/openai-assistantapi
```

## Usage

### Basic Example - Straightforward Conversation

Initiate a straightforward conversation and handle the results:

```javascript
import { OpenAIAssistant } from '@brainstack/openai-assistantapi';

const assistant = new OpenAIAssistant('your-api-key', 'your-assistant-id');

assistant.initThread().then(() => {
  assistant.handleRunStep().then(() => {
    console.log('Conversation completed.');
  });
});

assistant.on('complete', (data) => {
  console.log('Run completed:', data);
});

assistant.on('failed_canceled', (data) => {
  console.log('Run failed or canceled:', data);
});
```

### Example with Custom Function

Configure a custom function to be called by the assistant during the conversation:

```javascript
import { OpenAIAssistant } from '@brainstack/openai-assistantapi';

const assistant = new OpenAIAssistant('your-api-key', 'your-assistant-id');

assistant.addFunction('customFunction', (args) => {
  console.log('Custom function called with arguments:', args);
  // Implement custom function logic here
});

assistant.initThread().then(() => {
  assistant.handleRunStep().then(() => {
    console.log('Conversation completed.');
  });
});

assistant.on('complete', (data) => {
  console.log('Run completed:', data);
});

assistant.on('failed_canceled', (data) => {
  console.log('Run failed or canceled:', data);
});
```

### Subscribe to Get the Result

Subscribe to receive the result of the conversation:

```javascript
import { OpenAIAssistant } from '@brainstack/openai-assistantapi';

const assistant = new OpenAIAssistant('your-api-key', 'your-assistant-id');

assistant.on('run_completed', (data) => {
  console.log('Run completed:', data);
});

assistant.on('failed_canceled', (data) => {
  console.log('Run failed or canceled:', data);
});

assistant.handleCreateMessage('Hello, how are you?').then(() => {
  assistant.handleRunStep().then(() => {
    console.log('Conversation completed.');
  });
});
```

## Features

- Simplifies interaction with OpenAI's Assistant API.
- Event-driven interface streamlines development.
- Allows configuration of custom functions for assistant interaction.

## API

### `OpenAIAssistant(apiKey: string, assistantId: string)`

Constructor function to create an instance of the OpenAIAssistant class.

- `apiKey`: Your OpenAI API key.
- `assistantId`: ID of the assistant.

### `initThread(): Promise<void>`

Initializes the communication thread with the assistant.

### `handleRunStep(): Promise<void>`

Initiates a conversation step with the assistant.

### `on(eventName: string | RegExp, callback: Function): void`

Subscribes to events emitted by the assistant.

### `addFunction(name: string, func: Function): void`

Adds a custom function for the assistant to call during the conversation.

- `name`: Name of the function.
- `func`: Function to be called by the assistant.

### `removeFunction(name: string): void`

Removes a previously configured custom function from the assistant.

- `name`: Name of the function to remove.

==> openai-assistantapi-1.0.4.tgz: package/README.md <==
# @brainstack/openai-assistantapi

The `@brainstack/openai-assistantapi` package simplifies interaction with OpenAI's Assistant API by providing an event-driven interface. It streamlines the process, allowing developers to focus on implementation rather than intricacies.

## Features

- Simplifies interaction with OpenAI's Assistant API.
- Event-driven interface streamlines development.
- Allows configuration of custom tools for assistant interaction.

## Installation

Install the package via npm or yarn:

```bash
npm install @brainstack/openai-assistantapi
```

or

```bash
yarn add @brainstack/openai-assistantapi
```

## Getting Started

To get started, you need to create an instance of the `OpenAIAssistant` class by providing your OpenAI API key and the ID of your assistant. Once initialized, you can interact with the assistant using various methods provided by the interface.

## Examples

### Basic Conversation

Initiate a straightforward conversation and handle the results:

```javascript
import { OpenAIAssistant } from '@brainstack/openai-assistantapi';

const assistant = new OpenAIAssistant({apiKey:'your-api-key'}, 'your-assistant-id');

assistant.initThread().then(() => {
  assistant.handleRunStep().then(() => {
    console.log('Conversation completed.');
  });
});

assistant.on('complete', (data) => {
  console.log('Run completed:', data);
});

assistant.on('failed_canceled', (data) => {
  console.log('Run failed or canceled:', data);
});
```

### Custom Tool

Configure a custom tool to be used by the assistant during the conversation:

```javascript
import { OpenAIAssistant } from '@brainstack/openai-assistantapi';

const assistant = new OpenAIAssistant({apiKey:'your-api-key'}, 'your-assistant-id');

assistant.addTool('customTool', (args) => {
  console.log('Custom tool called with arguments:', args);
  // Implement custom tool logic here
});

assistant.initThread().then(() => {
  assistant.handleRunStep().then(() => {
    console.log('Conversation completed.');
  });
});

assistant.on('complete', (data) => {
  console.log('Run completed:', data);
});

assistant.on('failed_canceled', (data) => {
  console.log('Run failed or canceled:', data);
});
```

### Subscribe for Results

Subscribe to receive the result of the conversation:

```javascript
import { OpenAIAssistant } from '@brainstack/openai-assistantapi';

const assistant = new OpenAIAssistant({apiKey:'your-api-key'}, 'your-assistant-id');

assistant.on('run_completed', (data) => {
  console.log('Run completed:', data);
});

assistant.on('failed_canceled', (data) => {
  console.log('Run failed or canceled:', data);
});

assistant.handleCreateMessage('Hello, how are you?').then(() => {
  assistant.handleRunStep().then(() => {
    console.log('Conversation completed.');
  });
});
```

## API

### `OpenAIAssistant({apiKey: string}, assistantId: string)`

Constructor function to create an instance of the OpenAIAssistant class.

- `apiKey`: Your OpenAI API key.
- `assistantId`: ID of the assistant.

### `initThread(): Promise<void>`

Initializes the communication thread with the assistant.

### `handleRunStep(): Promise<void>`

Initiates a conversation step with the assistant.

### `on(eventName: string | RegExp, callback: Function): void`

Subscribes to events emitted by the assistant.

### `addTool(name: string, tool: Function): void`

Adds a custom tool for the assistant to use during the conversation.

- `name`: Name of the tool.
- `tool`: Function to be used by the assistant.

### `removeTool(name: string): void`

Removes a previously configured custom tool from the assistant.

- `name`: Name of the tool to remove.
